/*  
 *  - - - - - - - - - - 
 *   g a l _ b p n 0 0  
 *  - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  CEO-based bias-precession-nutation matrix.  
 *  
 *  This routine is an independent translation of the FORTRAN routine  
 *  BPN2000 by Patrick Wallace Annexe to IERS Conventions 2000, Cahpter 5  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *     x,y                 d        CIP coordinates
 *     s                   d        the quantity s (radians)
 *
 *  Returned:
 *     rbpn             d[3][3]     intermediate-to-celestial matrix ("Q")
 *
 *  Called:
 *
 *     gal_ir                       Initialize an r-matrix to the identity matrix
 *     gal_rz                       Rotate an r-matrix about the z-axis
 *     gal_rxr                      Multiply two r-matrices
 *
 *  This revision:
 *  
 *     2002 November 26 ( c version 2008 April 27 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_BPN00_H_  
#define _GAL_BPN00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_bpn00  
 (  
    double x,  
    double y,  
    double s,
    double rbpn[3][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_BPN00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
