/*  
 *  - - - - - - -  
 *   g a l _ d r  
 *  - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Find determinant of an r-matrix.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     r                d[3][3]     r-matrix for determinant  
 *  
 *  Returned:
 *  
 *     gal_dr              d        determinant 
 *
 *  References:
 *
 *     Mathematics for Computing 1st Edition 1982 (1984 Reprint)
 *     McKeown G. P, and Rayward-Smith V. J.
 *     Page 144 
 *  
 *  This revision:
 *  
 *     2008 April 20  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_dr.h"
  
double  
gal_dr  
 (  
    double r[3][3]   
 ) 
 
{
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  return r[0][0] * r[1][1] * r[2][2] 
       - r[0][0] * r[1][2] * r[2][1]
       - r[0][1] * r[1][0] * r[2][2]
       + r[0][1] * r[1][2] * r[2][0]
       + r[0][2] * r[1][0] * r[2][1]
       - r[0][2] * r[1][1] * r[2][0] ;
          
/*  
 *  Finished.  
 */  
  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
