/*  
 *  - - - - - - -  
 *   g a l _ d r  
 *  - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Find determinant of an r-matrix.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     r                d[3][3]     r-matrix for determinant  
 *  
 *  Returned:
 *  
 *     gal_dr              d        determinant 
 *
 *
 *  References:
 *
 *     Mathematics for Computing 1st Edition 1982 (1984 Reprint)
 *     McKeown G. P, and Rayward-Smith V. J.
 *     Page 144 
 *  
 *  This revision:
 *  
 *     2008 April 20  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_DR_H_  
#define _GAL_DR_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_dr  
 (  
    double r[3][3]   
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_DR_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
