/*  
 *  - - - - - - - - - 
 *   g a l _ i n v r  
 *  - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Calculate inverse of an r-matrix.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *
 *  Given:
 *
 *     r                d[3][3]     r-matrix to find inverse of
 *  
 *  Returned:
 *  
 *     invr             d[3][3]     inverse of r-matrix  
 *  
 *  This revision:
 *  
 *     2000 April 20
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_invr.h"
#include "gal_dr.h"
  
void  
gal_invr  
 (  
    double r[3][3],
    double invr[3][3]  
 ) 
 
{

  double d ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*
  i, j -> row, column

  11 21   01 21   01 11 
  12 22   02 22   02 12 
  
  10 20   00 20   00 10 
  12 22   02 22   02 12 
  
  10 20   00 20   00 10 
  11 21   01 21   01 11 
*/

  d = 1.0 / gal_dr ( r ) ;
  
  invr[0][0] =        ( r[1][1] * r[2][2] - r[1][2] * r[2][1] ) * d ;
  invr[0][1] = -1.0 * ( r[0][1] * r[2][2] - r[0][2] * r[2][1] ) * d ;
  invr[0][2] =        ( r[0][1] * r[1][2] - r[0][2] * r[1][1] ) * d ;

  invr[1][0] = -1.0 * ( r[1][0] * r[2][2] - r[1][2] * r[2][0] ) * d ; 
  invr[1][1] =        ( r[0][0] * r[2][2] - r[0][2] * r[2][0] ) * d ; 
  invr[1][2] = -1.0 * ( r[0][0] * r[1][2] - r[0][2] * r[1][0] ) * d ; 

  invr[2][0] =        ( r[1][0] * r[2][1] - r[1][1] * r[2][0] ) * d ; 
  invr[2][1] = -1.0 * ( r[0][0] * r[2][1] - r[0][1] * r[2][0] ) * d ; 
  invr[2][2] =        ( r[0][0] * r[1][1] - r[0][1] * r[1][0] ) * d ; 
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
