/*  
 *  - - - - - - - - - - - - - -  
 *   g a l _ i n v r _ t e s t  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_invr routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_invr  
 *     gal_vdv
 *
 *  Notes:
 *  
 *  1) Test 1 comes from Vallado, Test 2 from McKeown.
 *
 *  2) invr[1][1] from Test 1 as published is 0.012681 which is incorrect
 *
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 248-250
 *
 *     Mathematics for Computing 1st Edition 1982 (1984 Reprint)
 *     McKeown G. P, and Rayward-Smith V. J.
 *     Page 885 
 *  
 *  This Revision:
 *  
 *     2008 April 20  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_invr_test.h"
#include "gal_invr.h"
#include "gal_test.h"
  
void  
gal_invr_test  
 (  
 ) 
 
{

    double r[3][3], invr[3][3] ;  
  
    extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Test 1 
 */
   
    r[0][0] =  21.3 ;  
    r[0][1] =  -1.1 ;  
    r[0][2] = -21.0 ;  
    r[1][0] =   2.0 ;  
    r[1][1] =  10.5 ;  
    r[1][2] =   4.0 ;  
    r[2][0] =  13.0 ;  
    r[2][1] =  22.0 ;  
    r[2][2] =  37.0 ;  
  
    gal_invr ( r, invr ) ;  
    gal_vdv ( invr[0][0],  0.035913, 1e-6, "gal_invr", "invr[0][0] 0" ) ;  
    gal_vdv ( invr[0][1], -0.050350, 1e-6, "gal_invr", "invr[0][1] 0" ) ;  
    gal_vdv ( invr[0][2],  0.025827, 1e-6, "gal_invr", "invr[0][2] 0" ) ;  
    gal_vdv ( invr[1][0], -0.002629, 1e-6, "gal_invr", "invr[1][0] 0" ) ;  
    gal_vdv ( invr[1][1],  0.126814, 1e-6, "gal_invr", "invr[1][1] 0" ) ;  /* Corrected from Vallado */
    gal_vdv ( invr[1][2], -0.015202, 1e-6, "gal_invr", "invr[1][2] 0" ) ;  
    gal_vdv ( invr[2][0], -0.011054, 1e-6, "gal_invr", "invr[2][0] 0" ) ;  
    gal_vdv ( invr[2][1], -0.057712, 1e-6, "gal_invr", "invr[2][1] 0" ) ;  
    gal_vdv ( invr[2][2],  0.026992, 1e-6, "gal_invr", "invr[2][2] 0" ) ;  

/*
 * Test 2
 */
 
    r[0][0] =  3.0 ;  
    r[0][1] =  0.0 ;  
    r[0][2] =  1.0 ;  
    r[1][0] = -4.0 ;  
    r[1][1] =  5.0 ;  
    r[1][2] =  0.0 ;  
    r[2][0] =  2.0 ;  
    r[2][1] =  7.0 ;  
    r[2][2] =  6.0 ;  
  
    gal_invr ( r, invr ) ;  
    gal_vdv ( invr[0][0],  30.0 / 52.0, 1e-12, "gal_invr", "invr[0][0] 1" ) ;  
    gal_vdv ( invr[0][1],   7.0 / 52.0, 1e-12, "gal_invr", "invr[0][1] 1" ) ;  
    gal_vdv ( invr[0][2],  -5.0 / 52.0, 1e-12, "gal_invr", "invr[0][2] 1" ) ;  
    gal_vdv ( invr[1][0],  24.0 / 52.0, 1e-12, "gal_invr", "invr[1][0] 1" ) ;  
    gal_vdv ( invr[1][1],  16.0 / 52.0, 1e-12, "gal_invr", "invr[1][1] 1" ) ;  
    gal_vdv ( invr[1][2],  -4.0 / 52.0, 1e-12, "gal_invr", "invr[1][2] 1" ) ;  
    gal_vdv ( invr[2][0], -38.0 / 52.0, 1e-12, "gal_invr", "invr[2][0] 1" ) ;  
    gal_vdv ( invr[2][1], -21.0 / 52.0, 1e-12, "gal_invr", "invr[2][1] 1" ) ;  
    gal_vdv ( invr[2][2],  15.0 / 52.0, 1e-12, "gal_invr", "invr[2][2] 1" ) ;  
     
    gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
